/***가구자료에서 모든 가구원의 성별, 연령, 가구주와의 관계 추출***/

clear 
cd "C:\klips\Stata"

use klips22h, clear

// h**0221-h**0235: 가구원 PID 1-15
// h**0241-h**0255: 성별 1-15
// h**0261-h**0275: 가구주와의 관계 1-15
// h**0361-h**0375: 만나이 1-15
// h**0421-h**0435: 추가탈락여부 1-15

keep if hwave22==1 // 22차에 조사된 가구만 남기기 
keep hhid22 h220221-h220235 h220241-h220255 h220261-h220275 h220361-h220375 h220421-h220435

// 기존 가구원 pid 변수(h**0221~h**0235) 변수를 pid1~pid15로 변수명 변경
local l=1
foreach pid of varlist h220221-h220235 {
rename `pid' pid`l'
local ++l
}

// 기존 성별 변수(h**0241~h**0255) 변수를 sex1~sex15로 변수명 변경
local j=1
foreach sex of varlist h220241-h220255 {
rename `sex' sex`j'
local ++j
}

// 기존 가구주와의 관계 (h**0261~h**0275) 변수를 rel1~rel15로 변수명 변경
local i=1
foreach rel of varlist h220261-h220275 {
rename `rel' rel`i'
local ++i
}

// 기존 만나이 변수(h**0361~h**0375) 변수를 age1~age15로 변수명 변경
local k=1
foreach age of varlist h220361-h220375 {
rename `age' age`k'
local ++k
}

// 기존 추가탈락여부 변수(h**0421~h**0435) 변수를 change1~change15로 변수명 변경
local m=1
foreach change of varlist h220421-h220435 {
rename `change' change`m'
local ++m
}

// 기존 가로형태 (1~15)로 나열되어있는 데이터를 세로형태로 하나의 변수로 변환하기 위해 reshape 활용
reshape long pid sex rel age change, i(hhid22) j(orderInHH) 
keep if change==1|change==2 // 이번 차수에서 조사된 가구와 가구원만 남기기(기존+신규)

lab var pid "가구원 PID"
lab var sex "성별"
lab var rel "가구주와의 관계"
lab var age "만나이"
lab var change "추가탈락여부"

tab1 sex rel age 


save "D:\klips\Stata\data\exaple.dta", replace 
































